@@ -10,6 +10,7 @@
 import datetime
 import errno
 import os
+import re
 import subprocess
 import sys
 import time
@@ -18,11 +19,10 @@ import psutil
 from psutil import AIX
 from psutil import BSD
 from psutil import LINUX
+from psutil import MACOS
 from psutil import OPENBSD
-from psutil import OSX
 from psutil import POSIX
 from psutil import SUNOS
-from psutil._compat import callable
 from psutil._compat import PY3
 from psutil.tests import APPVEYOR
 from psutil.tests import get_kernel_version
@@ -152,6 +152,10 @@ class TestProcess(unittest.TestCase):
         # remove path if there is any, from the command
         name_ps = os.path.basename(name_ps).lower()
         name_psutil = psutil.Process(self.pid).name().lower()
+        # ...because of how we calculate PYTHON_EXE; on MACOS this may
+        # be "pythonX.Y".
+        name_ps = re.sub(r"\d.\d", "", name_ps)
+        name_psutil = re.sub(r"\d.\d", "", name_psutil)
         self.assertEqual(name_ps, name_psutil)
 
     def test_name_long(self):
@@ -190,7 +194,7 @@ class TestProcess(unittest.TestCase):
                 p = psutil.Process()
                 self.assertRaises(psutil.NoSuchProcess, p.name)
 
-    @unittest.skipIf(OSX or BSD, 'ps -o start not available')
+    @unittest.skipIf(MACOS or BSD, 'ps -o start not available')
     def test_create_time(self):
         time_ps = ps("ps --no-headers -o start -p %s" % self.pid).split(' ')[0]
         time_psutil = psutil.Process(self.pid).create_time()
@@ -305,14 +309,10 @@ class TestSystemAPIs(unittest.TestCase):
         pids_ps.sort()
         pids_psutil.sort()
 
-        # on OSX and OPENBSD ps doesn't show pid 0
-        if OSX or OPENBSD and 0 not in pids_ps:
+        # on MACOS and OPENBSD ps doesn't show pid 0
+        if MACOS or OPENBSD and 0 not in pids_ps:
             pids_ps.insert(0, 0)
-
-        if pids_ps != pids_psutil:
-            difference = [x for x in pids_psutil if x not in pids_ps] + \
-                         [x for x in pids_ps if x not in pids_psutil]
-            self.fail("difference: " + str(difference))
+        self.assertEqual(pids_ps, pids_psutil)
 
     # for some reason ifconfig -a does not report all interfaces
     # returned by psutil
